#include <stdio.h>
#include <stdlib.h>

int main (void) {
  int j,k;
  printf("\nEnter an integer > ");
  scanf("%d", &j);
  while (abs(j) >=10) {
    k = j % 10;
    printf("\n%d",abs(k));
    j = j / 10;
  };
  printf("\n%d",j);
  printf("\nThat's all, have a nice day!\n");
  return(0);   		   
  
}		       
